@@ -2,12 +2,15 @@
 from __future__ import absolute_import, print_function, unicode_literals
 
 import os.path
+import platform
+import sys
 import threading
 import time
 
 import six
 from django.test import override_settings
 from django.utils.encoding import force_text
+from fluent_compiler.errors import FluentJunkFound
 from testfixtures import LogCapture
 
 from django_ftl import activate, deactivate, override
@@ -243,7 +246,12 @@ class TestBundles(TestBase):
                     (
                         'django_ftl.message_errors',
                         'ERROR',
-                        "FTL exception for locale [%s], message 'with-argument', args {}: FluentReferenceError(%s'%s:5:28: Unknown external: user',)" % (locale_expected, 'u' if six.PY2 else '', ftl_filename)
+                        "FTL exception for locale [%s], message 'with-argument', args {}: FluentReferenceError(%s'%s:5:28: Unknown external: user'%s)" % (
+                            locale_expected,
+                            'u' if six.PY2 else '',
+                            ftl_filename,
+                            ',' if sys.version_info < (3, 7) else ''
+                        )
                     )
                 )
 
@@ -255,6 +263,24 @@ class TestBundles(TestBase):
         run('en')
         run('en')
 
+    def test_check_all(self):
+        bundle = Bundle(['tests/errors.ftl'], default_locale='en')
+        errors = bundle.check_all(['en'])
+        assert len(errors) == 2
+        assert errors[0][0] is None
+        assert isinstance(errors[0][1], FluentJunkFound)
+
+        assert errors[1][0] == 'this-has-an-error'
+        assert isinstance(errors[1][1], TypeError)
+        assert errors[1][1].args == ("NUMBER() got an unexpected keyword argument 'xxx'",)
+
+    def test_custom_functions(self):
+        def os_name():
+            return platform.system()
+
+        bundle = Bundle(['tests/functions.ftl'], default_locale='en', functions={'OSNAME': os_name})
+        assert bundle.format('hello') == 'Hello Linux user!'
+
 
 class TestLocaleLookups(TestBase):
     # See https://tools.ietf.org/html/rfc4647#section-3.4
